######################################################################## 
likelihood_simul <- function(k,num_runs=10, targetQofI=2.0,
                             fertFile="../fert_rates_rescaled",
                             mortFile="../mort_rates_rescaled",
                             Mort=CDmort ,
                             Fert=birthUnscaled){
  
######
  ##  This function runs socsim num_runs times, using rates determined
  ## by the vecor k of scalefactors. After each socsim run, it calls
  ## getG() which  reads
  ## the resulting output files; calculates and stores the Quantity of
  ## Interest, in this case Josh's G. It returns a list which includes
  ## the likelihood of Socsim producing a Quantity of Interest =
  ## targetQofI when using the rates implied by the values of k.
  
  ##  takes as input:

  ##  k: a vector of 2 elements, which contains rescaling factors for
  ## age-specific fertility and mortality rates, respectively
  
  ## num_runs: the number of runs, with different seeds, that we want
  ## to have for each combination of parameters, to estimate the
  ## likelihood

  ## targetQofI: the true known quantity of interest on which the
  ## likelihood calculations are based.

  
  
  names(k)<-c("FertScale","MortScale")

  ## Step 1 Rescale the fertility and mortality rates by the k parameters
  ## write to files where socsim expects to find rates
  writeScaledFert(outfile=fertFile,
                  scaleFactor=k["FertScale"])
  
  
  writeScaledMort(outfile=mortFile,
                  Mort=Mort,
                  scaleFactor=k["MortScale"])
  
  
  ##Step 2: run the simulation num_runs times, after each run,
  ##calculate and store the quantity of interest, for now this is
  ##Josh's G

  
  QofI<-NULL # will hold vector of quantities of interest, for now G
                                        
  
  for (index in 1:num_runs){
    
    ## RUN SOCSIM
    ## Windows version for Rostock MPI 116 June 2010
    if(windows){
      terminal_command<- paste("cd ..&&","N:\\socsim\\bin\\socsim",
                               " calibration_exercise.sup ",
                               round(runif(1,min=1,max=10000)), sep=" ")
      shell(terminal_command,"cmd")
    }else{
     ## Unix version
      terminal_command<- paste("cd ..;","socsim",
                             " calibration_exercise.sup ",
                              round(runif(1,min=1,max=10000)), sep="")
      system(terminal_command)
    }
    
    ##ANALYZE THE OUTPUT
    QofI <-c(QofI,
             ## This is where we find G. some other function that
             ## read socsim output and returned some other number
             ## could be substituted.
             getG(opopfile="../SimResults/pop_output.opop")
             )
    
  }
  
  ## collect valuable information on the quantity of interest
  meanQofI <- mean(QofI,na.rm=T)
  ## if there is no variation in QofI we have a train wreck.
  sd_QofI <- ifelse(sd(QofI,na.rm=T) !=0,
                    sd(QofI,na.rm=T),
                    0.000001)

  
  ##standardization of G
 # standard_targetQofI <- (targetQofI - meanQofI)/sd_QofI
  ## compute the likelihood based on a normal approximation and
  ## deference to the Central Limit Theorem

##  like <- (exp(-((targetQofI - meanQofI)^2)/(2*(sd_QofI)^2))*
##           ((2*pi*(sd_QofI)^2)^(-0.5))) 

  like<- dnorm(x=targetQofI,mean=meanQofI,sd=sd_QofI)
  result <- list(likelihood=like,
                 targetQofI=targetQofI,
                 k=k,
                 meanQofI=meanQofI,
                 sdQofI=sd_QofI,
                 simulatedQofI= QofI)
  return(result)
  
}

########################################################################
